@@ -15,8 +15,6 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewplugin.h,v 1.22 2009/02/22 16:50:54 leonb Exp $
-
 #ifndef QDJVIEWPLUGIN_H
 #define QDJVIEWPLUGIN_H
 
@@ -33,8 +31,6 @@
 #include <QStringList>
 #include <QUrl>
 
-#ifdef Q_WS_X11
-
 #include "qdjvu.h"
 #include "qdjview.h"
 #include "djview.h"
@@ -126,8 +122,6 @@ private:
 };
 
 
-#endif // Q_WS_X11
-
 #endif // QDJVIEWPLUGIN_H
 
 /* -------------------------------------------------------------
